using System;
using System.Collections.Generic;

using skydiveLogs_api.Business.Interfaces;
using skydiveLogs_api.DomainService.Repositories;
using skydiveLogs_api.Domain;


namespace skydiveLogs_api.Business
{
    public class DropZoneService : IDropZoneService
    {
        public DropZoneService(IDropZoneRepository dropZoneRepository)
        {
            _dropZoneRepository = dropZoneRepository;
        }

        public void AddNewDz(DropZone newdropZone)
        {
            _dropZoneRepository.Add(newdropZone);
        }

        public void DeleteDzById(int id)
        {
            throw new NotImplementedException();
        }

        public IEnumerable<DropZone> GetAllDzs()
        {
            return _dropZoneRepository.GetAll();
        }

        public DropZone GetDzById(int id)
        {
            return _dropZoneRepository.GetById(id);
        }

        public bool UpdateDz(int id, DropZone dropZone)
        {
            dropZone.Id = id;

            return _dropZoneRepository.Update(dropZone);
        }

        private readonly IDropZoneRepository _dropZoneRepository;
    }
}
